==> onos-yang-runtime-2.2.0-b1-sources.jar: org/onosproject/yang/gen/v1/ietfl3vpnsvc/rev20160730/ietfl3vpnsvc/transportconstraints/DefaultTransportConstraints.java <==
/*
 * Copyright 2017-present Open Networking Laboratory
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.transportconstraints;

import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.transportconstraints.transportconstraints.MulticastTransportConstraints;
import org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.transportconstraints.transportconstraints.UnicastTransportConstraints;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of transportConstraints.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultTransportConstraints extends InnerModelObject implements TransportConstraints {
    protected UnicastTransportConstraints unicastTransportConstraints;
    protected MulticastTransportConstraints multicastTransportConstraints;

    @Override
    public UnicastTransportConstraints unicastTransportConstraints() {
        return unicastTransportConstraints;
    }

    @Override
    public MulticastTransportConstraints multicastTransportConstraints() {
        return multicastTransportConstraints;
    }

    @Override
    public void unicastTransportConstraints(UnicastTransportConstraints unicastTransportConstraints) {
        this.unicastTransportConstraints = unicastTransportConstraints;
    }

    @Override
    public void multicastTransportConstraints(MulticastTransportConstraints multicastTransportConstraints) {
        this.multicastTransportConstraints = multicastTransportConstraints;
    }

    @Override
    public int hashCode() {
        return Objects.hash(unicastTransportConstraints, multicastTransportConstraints);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultTransportConstraints) {
            DefaultTransportConstraints other = (DefaultTransportConstraints) obj;
            return
                Objects.equals(unicastTransportConstraints, other.unicastTransportConstraints) &&
                Objects.equals(multicastTransportConstraints, other.multicastTransportConstraints);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("unicastTransportConstraints=" + unicastTransportConstraints)
            .add("multicastTransportConstraints=" + multicastTransportConstraints)
            .toString();
    }


    /**
     * Creates an instance of defaultTransportConstraints.
     */
    public DefaultTransportConstraints() {
    }

}

==> onos-yang-runtime-2.3.1-sources.jar: org/onosproject/yang/gen/v1/ietfl3vpnsvc/rev20160730/ietfl3vpnsvc/transportconstraints/DefaultTransportConstraints.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.transportconstraints;

import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.transportconstraints.transportconstraints.MulticastTransportConstraints;
import org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.transportconstraints.transportconstraints.UnicastTransportConstraints;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of transportConstraints.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultTransportConstraints extends InnerModelObject implements TransportConstraints {
    protected UnicastTransportConstraints unicastTransportConstraints;
    protected MulticastTransportConstraints multicastTransportConstraints;

    @Override
    public UnicastTransportConstraints unicastTransportConstraints() {
        return unicastTransportConstraints;
    }

    @Override
    public MulticastTransportConstraints multicastTransportConstraints() {
        return multicastTransportConstraints;
    }

    @Override
    public void unicastTransportConstraints(UnicastTransportConstraints unicastTransportConstraints) {
        this.unicastTransportConstraints = unicastTransportConstraints;
    }

    @Override
    public void multicastTransportConstraints(MulticastTransportConstraints multicastTransportConstraints) {
        this.multicastTransportConstraints = multicastTransportConstraints;
    }

    @Override
    public int hashCode() {
        return Objects.hash(unicastTransportConstraints, multicastTransportConstraints);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultTransportConstraints) {
            DefaultTransportConstraints other = (DefaultTransportConstraints) obj;
            return
                Objects.deepEquals(unicastTransportConstraints, other.unicastTransportConstraints) &&
                Objects.deepEquals(multicastTransportConstraints, other.multicastTransportConstraints);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("unicastTransportConstraints=" + unicastTransportConstraints)
            .add("multicastTransportConstraints=" + multicastTransportConstraints)
            .toString();
    }


    /**
     * Creates an instance of defaultTransportConstraints.
     */
    public DefaultTransportConstraints() {
    }

}
